@@ -15,7 +15,6 @@ my $obj = Map::Tube::Sofia->new;
 # GraphViz object.
 my $g = Map::Tube::GraphViz->new(
         'callback_node' => \&node_color_without_label,
-        'driver' => 'neato',
         'tube' => $obj,
 ); 
 
@@ -26,4 +25,4 @@ $g->graph('Sofia.png');
 system "ls -l Sofia.png";
 
 # Output like:
-# TODO
\ No newline at end of file
+# -rw-r--r-- 1 skim skim 78098 Dec 23 11:47 Sofia.png
\ No newline at end of file
